//-----------------------
// 定数の定義
//-----------------------
const int SW = 2;           // スイッチの入力ピン
const int B_LED = 3;        // 青色LEDの出力ピン
const int O_LED = 4;        // 橙色LEDの出力ピン

//スイッチの回路は負論理なので、ONがLOWになる
const int SW_ON = LOW;
const int SW_OFF = HIGH;

//-----------------------
// フラグの定義
//-----------------------
const int FLG_ON = 1;
const int FLG_OFF = 0;

//-----------------------
// グローバル変数の定義
//-----------------------
int G_oldval = SW_OFF;           // スイッチの状態 （初期設定はOFF）
int G_state = FLG_OFF;           // LED点滅の状態 （初期設定はOFF）

//-----------------------
//最初に１回だけ実行する処理
//-----------------------
void setup() {
  pinMode(SW, INPUT);        // SWを入力モードに設定
  pinMode(B_LED, OUTPUT);    //青色LEDを出力モードに設定
  pinMode(O_LED, OUTPUT);    //橙色LEDを出力モードに設定
}

//-----------------------
//繰り返し実行する処理
//-----------------------
void loop() {
  int val = digitalRead(SW);    // スイッチの状態を読み取る
  
  //スイッチがON、前回がOFFだった時
  if( val == SW_ON && G_oldval == SW_OFF ){
    //LED点滅の状態を切り替える
    if(G_state == FLG_ON){    // フラグがONの時
      G_state = FLG_OFF;        // OFF
    } else {                  // フラグがOFFの時
      G_state = FLG_ON;        // ON
    }
    delay(10);                // チャタリング防止のウエイト
  }

  G_oldval = val;            // スイッチの状態をG_oldvalへ保存

  //LEDの点滅状態を開始するとき
  if (G_state == FLG_ON){       // LEDの点滅状態がONの時
    digitalWrite(O_LED, HIGH);    // 橙LED点灯
    delay(300);                   // 0.3秒待つ
    digitalWrite(O_LED, LOW);     // 橙LED消灯
    delay(300);                   // 0.3秒待つ

    digitalWrite(B_LED, HIGH);    // 青LED点灯
    delay(300);                   // 0.3秒待つ
    digitalWrite(B_LED, LOW);     // 青LED消灯
    delay(300);                   // 0.3秒待つ
  } else {                      // OFFのとき
    digitalWrite(B_LED,LOW);      // 青LED消灯
    digitalWrite(O_LED,LOW);      // 橙LED消灯
  }
}
